smartcard.PassThruCardService.PassThruCardService

# ``smartcard`.`PassThruCardService`.`PassThruCardService``

class documentation

`class PassThruCardService(CardService.CardService):`

View In Hierarchy

Pass-thru card service class.

Static Method | `supports` | Returns True if the cardname is supported by the card service. The PassThruCardService supports all cardnames and always returns True.
Method | `__init__` | Construct a pass-thru card service.

Inherited from `CardService`:

Method | `__del__` | Destructor. Disconnect card and destroy card service resources.
Instance Variable | `cardname` | Undocumented
Instance Variable | `connection` | Undocumented

def supports(cardname):
overrides `smartcard.CardService.CardService.supports`

Returns True if the cardname is supported by the card service. The PassThruCardService supports all cardnames and always returns True.

def __init__(self, connection, cardname=None):
overrides `smartcard.CardService.CardService.__init__`

Construct a pass-thru card service.

Parameters
connection | the CardConnection used to access the smart card
cardname | Undocumented